
*** International Regime Formation Revisited: Explaining Ratification Behavior With Respect to Long Range Transboundary Air Pollution Agreements in Europe

*** Thomas Bernauer, Sophie Perrin, ETH Zurich, Switzerland
*** Do-File march 2010 (Cleaned-Up Data Set)
*** To use with AN_EUP_08032010.dta 


*************************
*************************

clear
version 10

set matsize 800
set mem 1000m
capture log close
set more off


* Open the file AN_EUP_08032010 to replicate the analysis with the code below. Do not change the name of the file!

* use AN_EUP_08032010, clear

xtset idnr year


*** Var labels

des



lab var ratif "Ratification"
lab var L_others "Others (#)"
lab var L_others_pop "Others (pop)"
lab var L_others_GDP "Others (gdp)"
lab var L_neighbors "Neighbors"
lab var L_big_3 "Big countries"
lab var L_competitors "Competitors"

lab var others "Others (#)"
lab var others_pop "Others (pop)"
lab var others_GDP "Others (gdp)"
lab var neighbors "Neighbors"
lab var big_3 "Big countries"
lab var competitors "Competitors"


lab var pop "Population"
lab var gdp "GDP"
lab var gdppc "GDP per capita"
lab var trade_op "Trade openness"
lab var veto_players "Veto Players"

lab var EU_status "EU affiliation"
lab var polluter "Transboundary polluter"

lab var t "Age of treaty"
lab var t2 "Age of treaty^2"
lab var t3 "Age of treaty^3"
lab var post_coldwar "After 1989"

lab var treatyno "Treaty"



save AN_EUP_08032010, replace





* Table 2

logit ratif L_others L_neighbors L_big_3 L_competitors pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, cluster(cowcode) //

outreg2 using RT_maerz10_a3, word bdec(4) tdec(4) e(N all)


logit ratif pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, cluster(cowcode) 

outreg2 using RT_maerz10_a3, word bdec(4) tdec(4) e(N all) append


logit ratif L_others pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, cluster(cowcode) 

outreg2 using RT_maerz10_a3, word bdec(4) tdec(4) e(N all) append


logit ratif L_neighbors pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, cluster(cowcode) 

outreg2 using RT_maerz10_a3, word bdec(4) tdec(4) e(N all) append


logit ratif L_big_3 pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, cluster(cowcode) 

outreg2 using RT_maerz10_a3, word bdec(4) tdec(4) e(N all) append


logit ratif L_competitors pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, cluster(cowcode) 

outreg2 using RT_maerz10_a3, word bdec(4) tdec(4) e(N all) append


* Table 3

logit ratif L_others L_others_GDP L_others_pop pop gdppc trade_op /// 
veto_players polluter t t2 t3, cluster(cowcode) //

outreg2 using RT_maerz10_a3b, word bdec(4) tdec(4) e(N all)


logit ratif L_others pop gdppc trade_op /// 
veto_players polluter t t2 t3, cluster(cowcode) 

outreg2 using RT_maerz10_a3b, word bdec(4) tdec(4) e(N all) append


logit ratif L_others_GDP pop gdppc trade_op /// 
veto_players polluter t t2 t3, cluster(cowcode) 

outreg2 using RT_maerz10_a3b, word bdec(4) tdec(4) e(N all) append


clogit ratif L_others_pop pop gdppc trade_op /// 
veto_players t t2 t3, group(cowcode) 

outreg2 using RT_maerz10_a3b, word bdec(4) tdec(4) e(N all) append


clogit ratif L_others_pop pop gdppc trade_op /// 
veto_players t t2 t3, group(treatyno) 

outreg2 using RT_maerz10_a3b, word bdec(4) tdec(4) e(N all) append



** Figure 1 and Table 6.1 in companion materials: simulated probabilities


save table4, replace


* polluter
sum polluter

estsimp logit ratif L_others_pop pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, cluster(cowcode) 

setx mean
setx polluter min
simqi

setx mean
simqi fd(prval(1)) changex(polluter min max) 
simqi fd(prval(1)) changex(polluter min mean) 
simqi fd(prval(1)) changex(polluter mean max) 



* Figure 1: plot polluter

tab polluter

capture drop POLLUTER
capture drop plo
capture drop phi  
capture drop av
capture drop pi


gen plo = .
label variable plo "99% confidence interval"	//lower bound
gen phi = .
label variable phi "99% confidence interval"	//upper bound
gen av = .
label variable av "expected cooperation"

generate POLLUTER = _n/10 in 1/30

tab POLLUTER 
setx mean
local a = 0.1
while `a' <= 3.4 {
   setx polluter `a'
   simqi, prval(1) genpr(pi)		// simulate predicted probabilities stored in pi
   _pctile pi, p(2.5,97.5)			// generate percentiles (2.5; 97.5 for confinterv) of pi stored in r
   replace plo = r(r1) if POLLUTER==`a'	// plo = 2.5 percentile (upper bound)
   replace phi = r(r2) if POLLUTER==`a'	// phi = 97.5 percentile (lower bound)
   sum pi
   local c = r(mean)
   replace av = `c' if POLLUTER==`a'		// predicted probability 
   drop pi
   local a = `a' + 0.1 // oder + 1mio?
}

sort POLLUTER

twoway (rarea plo phi POLLUTER, color(gs11)) (line av POLLUTER), scheme(s2mono)


* trad_op

use AN_EUP_08032010, clear

save table4b, replace


estsimp logit ratif L_others_pop pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, cluster(cowcode) 


setx mean

setx trade_op min

simqi

setx mean

simqi fd(prval(1)) changex(trade_op min max) 
simqi fd(prval(1)) changex(trade_op min mean) 
simqi fd(prval(1)) changex(trade_op mean max)


* plot

tab trade_op

tab trade_op // 0,  .9962561

capture drop TRADEOP
capture drop plo
capture drop phi  
capture drop av
capture drop pi


gen plo = .
label variable plo "99% confidence interval"	//lower bound
gen phi = .
label variable phi "99% confidence interval"	//upper bound
gen av = .
label variable av "expected cooperation"


generate TRADEOP = (_n+18)-1 in 1/10 // 

tab TRADEOP

setx mean

local a = 18
while `a' <= 27 {
   setx trade_op `a'
   simqi, prval(1) genpr(pi)		// simulate predicted probabilities stored in pi
   _pctile pi, p(2.5,97.5)			// generate percentiles (2.5; 97.5 for confinterv) of pi stored in r
   replace plo = r(r1) if TRADEOP==`a'	// plo = 2.5 percentile (upper bound)
   replace phi = r(r2) if TRADEOP==`a'	// phi = 97.5 percentile (lower bound)
   sum pi
   local c = r(mean)
   replace av = `c' if TRADEOP==`a'		// predicted probability 
   drop pi
   local a = `a' + 0.5 // oder + 1mio?
}

sort TRADEOP

twoway (rarea plo phi TRADEOP, color(gs11)) (line av TRADEOP), scheme(s2mono) // scale ok aberNIX! NAME OtherWP verb!






* competitors

use AN_EUP_08032010, clear

save table4c, replace

sum L_competitors


estsimp logit ratif L_competitors pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, cluster(cowcode) 

setx mean

setx L_competitors 0

simqi


setx mean

simqi fd(prval(1)) changex(L_competitors min max) 
simqi fd(prval(1)) changex(L_competitors min mean) 
simqi fd(prval(1)) changex(L_competitors mean max) 



* plot competitors

tab L_competitors //

capture drop Tradepartners
capture drop plo
capture drop phi  
capture drop av
capture drop pi



gen plo = .
label variable plo "99% confidence interval"	//lower bound
gen phi = .
label variable phi "99% confidence interval"	//upper bound
gen av = .
label variable av "expected cooperation"



generate Competitors = _n-1 in 1/101 //

tab Competitors

setx mean

local a = 0
while `a' <= 100 {
   setx L_competitors `a'
   simqi, prval(1) genpr(pi)		// simulate predicted probabilities stored in pi
   _pctile pi, p(2.5,97.5)			// generate percentiles (2.5; 97.5 for confinterv) of pi stored in r
   replace plo = r(r1) if Competitors==`a'	// plo = 2.5 percentile (upper bound)
   replace phi = r(r2) if Competitors==`a'	// phi = 97.5 percentile (lower bound)
   sum pi
   local c = r(mean)
   replace av = `c' if Competitors==`a'		// predicted probability 
   drop pi
   local a = `a' + 1 // 
}

sort Competitors

twoway (rarea plo phi Competitors, color(gs11)) (line av Competitors), scheme(s2mono) 




* other



use AN_EUP_08032010, clear

save table4d, replace




sum L_others


estsimp logit ratif L_others pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, cluster(cowcode) 


setx mean

setx L_others 0

simqi


setx mean

simqi fd(prval(1)) changex(L_others min max) 
simqi fd(prval(1)) changex(L_others min mean) 
simqi fd(prval(1)) changex(L_others mean max) 



* PLOT

tab L_others // 

capture drop lperc_tot
capture drop plo
capture drop phi  
capture drop av
capture drop pi



gen plo = .
label variable plo "99% confidence interval"	//lower bound
gen phi = .
label variable phi "99% confidence interval"	//upper bound
gen av = .
label variable av "expected cooperation"



generate lperc_tot = _n in 1/100 // 

tab lperc_tot

setx mean

local a = 0
while `a' <= 100 {
   setx L_others `a'
   simqi, prval(1) genpr(pi)		// simulate predicted probabilities stored in pi
   _pctile pi, p(2.5,97.5)			// generate percentiles (2.5; 97.5 for confinterv) of pi stored in r
   replace plo = r(r1) if lperc_tot==`a'	// plo = 2.5 percentile (upper bound)
   replace phi = r(r2) if lperc_tot==`a'	// phi = 97.5 percentile (lower bound)
   sum pi
   local c = r(mean)
   replace av = `c' if lperc_tot==`a'		// predicted probability 
   drop pi
   local a = `a' + 1 //
}

sort lperc_tot

twoway (rarea plo phi lperc_tot, color(gs11)) (line av lperc_tot), scheme(s2mono) // 





* sim prob for l_other_pop

use AN_EUP_08032010, clear

save table4e, replace


sum L_others_pop

estsimp logit ratif L_others_pop pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, cluster(cowcode) 

setx mean
setx L_others_pop 0

simqi // 

setx mean

simqi fd(prval(1)) changex(L_others_pop min max) 
simqi fd(prval(1)) changex(L_others_pop min mean) 
simqi fd(prval(1)) changex(L_others_pop mean max) 




* L_neigbors

use AN_EUP_08032010, clear

save table4f, replace


sum L_neighbors


estsimp logit ratif L_neighbors pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, cluster(cowcode) 


setx mean

setx L_neighbors 0

simqi


setx mean

simqi fd(prval(1)) changex(L_neighbors min max) 
simqi fd(prval(1)) changex(L_neighbors min mean) 
simqi fd(prval(1)) changex(L_neighbors mean max) 



* big_3

use AN_EUP_08032010, clear

save table4g, replace

sum L_big_3


estsimp logit ratif L_big_3 pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, cluster(cowcode) 



setx mean

setx L_big_3 0

simqi


setx mean

simqi fd(prval(1)) changex(L_big_3 min max) 
simqi fd(prval(1)) changex(L_big_3 min mean) 
simqi fd(prval(1)) changex(L_big_3 mean max) 


* pop

use AN_EUP_08032010, clear

save table4h, replace

sum pop


estsimp logit ratif L_others_pop pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, cluster(cowcode) 

setx mean

setx pop 0

simqi

setx mean

simqi fd(prval(1)) changex(pop min max) 
simqi fd(prval(1)) changex(pop min mean) 
simqi fd(prval(1)) changex(pop mean max)




**************************************************************************************************************************************


* COMPANION MATERIALS


/*


gen others = perc_totratif2
gen others_pop = L
gen others_GDP = C
gen neighbors = percnb
gen big_3 = BIGRAT
gen competitors = TPr_shNR


*/



use AN_EUP_08032010, clear


*** 1: Descriptive Statistics 

sum ratif L_others L_neighbors L_others_pop L_others_GDP L_big_3 L_competitors gdp pop ///
others_pop others_GDP big_3 competitors lUK lFrance lGER ///
gdppc trade_op veto_players polluter post_coldwar EU_status ///
treatyno t t2 t3 


*** 4: Cross-Correlations

pwcorr ratif L_others_pop L_neighbors L_others_GDP L_big_3 L_competitors gdp pop gdppc trade_op veto_players polluter ///
post_coldwar EU_status treatyno t t2 t3 



*** 5: Properties of the models shown in Table 2 of the article


logit ratif L_others_pop L_neighbors L_big_3 L_competitors pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, cluster(cowcode) //

outreg2 using RT_M110_a3, word bdec(4) tdec(4) e(N all)
fitstat


logit ratif pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, cluster(cowcode) 

outreg2 using RT_M110_a3, word bdec(4) tdec(4) e(N all) append
fitstat


logit ratif L_others pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3 if e(sample), cluster(cowcode) 


outreg2 using RT_M110_a3, word bdec(4) tdec(4) e(N all) append
fitstat


logit ratif L_neighbors pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3 if e(sample), cluster(cowcode) 

outreg2 using RT_M110_a3, word bdec(4) tdec(4) e(N all) append
fitstat


logit ratif L_big_3 pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3 if e(sample), cluster(cowcode) 

outreg2 using RT_M110_a3, word bdec(4) tdec(4) e(N all) append
fitstat


logit ratif L_competitors pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3 if e(sample), cluster(cowcode) 

outreg2 using RT_M110_a3, word bdec(4) tdec(4) e(N all) append
fitstat





*** 6: Simulated probabilities (see above, too: Figure 1 and Table 6.1)



* Figure 6.1 (WITH TIME: simulation)

use AN_EUP_08032010, clear

save figA1, replace


sum t

estsimp logit ratif pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, cluster(cowcode) 


tab t
capture drop time
capture drop plo
capture drop phi  
capture drop av
capture drop pi


gen plo = .
label variable plo "99% confidence interval"	//lower bound
gen phi = .
label variable phi "99% confidence interval"	//upper bound
gen av = .
label variable av "expected cooperation"



generate time = _n-1 in 1/14 //
tab time

setx mean

local a = 0
while `a' <= 13 {
   setx t `a' t2 (`a'^2) t3 (`a'^3)
   simqi, prval(1) genpr(pi)		// simulate predicted probabilities stored in pi
   _pctile pi, p(2.5,97.5)			// generate percentiles (2.5; 97.5 for confinterv) of pi stored in r
   replace plo = r(r1) if time==`a'	// plo = 2.5 percentile (upper bound)
   replace phi = r(r2) if time==`a'	// phi = 97.5 percentile (lower bound)
   sum pi
   local c = r(mean)
   replace av = `c' if time==`a'		// predicted probability 
   drop pi
   local a = `a' + 1
}
sort time
twoway (rarea plo phi time, color(gs11)) (line av time), scheme(s2mono) // xsc(r(0 18))





* Figure 6.2, 6.4, 6.5, 6.7: see fig.1 above


* Figure 6.3:

* other_pop

use AN_EUP_08032010, clear

save figA3_2, replace


tab L_others_pop // 0,  .9962561


estsimp logit ratif L_others_pop pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, cluster(cowcode) 


* plot

capture drop others_P
capture drop plo
capture drop phi  
capture drop av
capture drop pi


gen plo = .
label variable plo "99% confidence interval"	//lower bound
gen phi = .
label variable phi "99% confidence interval"	//upper bound
gen av = .
label variable av "expected cooperation"


generate others_P = (_n-1)/100 in 1/101 // ???? 0 - 1 --> 1. =0.01?

tab others_P

setx mean

local a = 0
while `a' <= 1 {
   setx L_others_pop `a'
   simqi, prval(1) genpr(pi)		// simulate predicted probabilities stored in pi
   _pctile pi, p(2.5,97.5)			// generate percentiles (2.5; 97.5 for confinterv) of pi stored in r
   replace plo = r(r1) if others_P==`a'	// plo = 2.5 percentile (upper bound)
   replace phi = r(r2) if others_P==`a'	// phi = 97.5 percentile (lower bound)
   sum pi
   local c = r(mean)
   replace av = `c' if others_P==`a'		// predicted probability 
   drop pi
   local a = `a' + 0.01 // weg mit + 1? --> NEIN spinnt und hrt nicht mehr auf zu rechnen!
}

sort others_P

twoway (rarea plo phi others_P, color(gs11)) (line av others_P), scheme(s2mono) // 





* Figure 6.6:

use AN_EUP_08032010, clear

save figA3_1, replace

sum pop

estsimp logit ratif L_others_pop pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, cluster(cowcode) 

setx mean

setx pop 0

simqi


setx mean

simqi fd(prval(1)) changex(pop min max) 
simqi fd(prval(1)) changex(pop min mean) 
simqi fd(prval(1)) changex(pop mean max)


* PLOT pop 

tab pop

capture drop POP
capture drop plo
capture drop phi  
capture drop av
capture drop pi

gen plo = .
label variable plo "99% confidence interval"	//lower bound
gen phi = .
label variable phi "99% confidence interval"	//upper bound
gen av = .
label variable av "expected cooperation"

generate POP = _n-1 in 1/13 // 


tab POP

setx mean

local a = 0 // 3.475
while `a' <= 12 {
   setx pop `a'
   simqi, prval(1) genpr(pi)		// simulate predicted probabilities stored in pi
   _pctile pi, p(2.5,97.5)			// generate percentiles (2.5; 97.5 for confinterv) of pi stored in r
   replace plo = r(r1) if POP==`a'	// plo = 2.5 percentile (upper bound)
   replace phi = r(r2) if POP==`a'	// phi = 97.5 percentile (lower bound)
   sum pi
   local c = r(mean)
   replace av = `c' if POP==`a'		// predicted probability 
   drop pi
   local a = `a' + 1 // oder + 1mio?
}

sort POP

twoway (rarea plo phi POP, color(gs11)) (line av POP), scheme(s2mono) // scale ok aberNIX! NAME OtherWP verb!





* Table 6.2 

* CH

use AN_EUP_08032010, clear

save tableA6_1, replace


list L_others_pop pop gdppc trade_op veto_players polluter post_coldwar t t2 t3 if cowcode ==225 & year == 2000


estsimp logit ratif L_others_pop pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, cluster(cowcode) 

setx mean
setx pop 8.879642 gdppc 10.44937 trade_op 25.44534 veto_players 0.6327884 polluter 0.4387755

simqi // Pr(Y=1)  



* UK

use AN_EUP_08032010, clear

save tableA6_2, replace


list L_others_pop pop gdppc trade_op veto_players polluter post_coldwar t t2 t3 if cowcode ==200 & year == 2000


estsimp logit ratif L_others_pop pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, cluster(cowcode) 

setx mean
setx pop 10.99781 gdppc 10.24053 trade_op 26.72692 veto_players 0.3517931 polluter 2.376039

simqi // Pr(Y=1) 


* BEL

use AN_EUP_08032010, clear

save tableA6_3, replace


list L_others_pop pop gdppc trade_op veto_players polluter post_coldwar t t2 t3 if cowcode ==211 & year == 2000



estsimp logit ratif L_others_pop pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, cluster(cowcode) 

setx mean
setx pop 9.235229 gdppc 10.31339 trade_op 26.00299 veto_players 0.714431  polluter 2.124629

simqi // Pr(Y=1)  



* RUM

use AN_EUP_08032010, clear

save tableA6_4, replace


list L_others_pop pop gdppc trade_op veto_players polluter post_coldwar t t2 t3 if cowcode ==211 & year == 2000


estsimp logit ratif L_others_pop pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, cluster(cowcode) 

setx mean
setx pop 9.235229 gdppc 10.31339 trade_op 26.00299 veto_players 0.714431  polluter 2.124629

simqi // Pr(Y=1) 




* IT


use AN_EUP_08032010, clear

save tableA6_5, replace


list L_others_pop pop gdppc trade_op veto_players polluter if cowcode == 325 & year == 2000


estsimp logit ratif L_others_pop pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, cluster(cowcode) 

setx mean
setx pop 10.9499 gdppc 10.22526 trade_op 26.41664 veto_players 0.4222979  polluter 0.9167327

simqi // Pr(Y=1)  


* Norway


use AN_EUP_08032010, clear

save tableA6_6, replace

list L_others_pop pop gdppc trade_op veto_players polluter if cowcode == 385 & year == 2000


estsimp logit ratif L_others_pop pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, cluster(cowcode) 

setx mean
setx pop 8.409831 gdppc 10.68919 trade_op 25.08401 veto_players 0.5177137  polluter 0.204947

simqi // Pr(Y=1)  



* PT

use AN_EUP_08032010, clear

save tableA6_7, replace


list L_others_pop pop gdppc trade_op veto_players polluter if cowcode == 235 & year == 2000


estsimp logit ratif L_others_pop pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, cluster(cowcode) 

setx mean
setx pop 9.23267  gdppc 9.894365 trade_op 24.23552 veto_players 0.4125815  polluter 2.179389 

simqi // Pr(Y=1)


* EST

use AN_EUP_08032010, clear

save tableA6_8, replace

list L_others_pop pop gdppc trade_op veto_players polluter if cowcode == 366 & year == 2000

estsimp logit ratif L_others_pop pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, cluster(cowcode) 

setx mean
setx pop 7.22221  gdppc 9.294613 trade_op 22.29217 veto_players 0.5508911  polluter 1.861702  

simqi // Pr(Y=1)







*** 7: Robustness Checks

* Table 7.1 

clogit ratif L_neighbors L_big_3 L_competitors pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, group(treatyno) // 

outreg2 using RT_maerz10_a4, word bdec(4) tdec(4) e(N all)


clogit ratif L_neighbors pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, group(cowcode) 

outreg2 using RT_maerz10_a4, word bdec(4) tdec(4) e(N all) append


clogit ratif L_neighbors pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, group(treatyno) 

outreg2 using RT_maerz10_a4, word bdec(4) tdec(4) e(N all) append


clogit ratif L_big_3 pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, group(cowcode) 

outreg2 using RT_maerz10_a4, word bdec(4) tdec(4) e(N all) append


clogit ratif L_big_3 pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, group(treatyno) 

outreg2 using RT_maerz10_a4, word bdec(4) tdec(4) e(N all) append


clogit ratif L_competitors pop gdppc trade_op veto_players post_coldwar t t2 t3, group(cowcode) 
outreg2 using RT_maerz10_a4, word bdec(4) tdec(4) e(N all) append


clogit ratif L_competitors pop gdppc trade_op veto_players post_coldwar t t2 t3, group(treatyno) 
outreg2 using RT_maerz10_a4, word bdec(4) tdec(4) e(N all) append




* Table 7.2: Main results, without lags


logit ratif pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, cluster(cowcode) 

outreg2 using RT_maerz10_a1, word bdec(4) tdec(4) e(N all)


logit ratif others_pop pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, cluster(cowcode) 

outreg2 using RT_maerz10_a1, word bdec(4) tdec(4) e(N all) append


logit ratif neighbors pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, cluster(cowcode) 

outreg2 using RT_maerz10_a1, word bdec(4) tdec(4) e(N all) append


logit ratif big_3 pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, cluster(cowcode) 

outreg2 using RT_maerz10_a1, word bdec(4) tdec(4) e(N all) append


logit ratif competitors pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, cluster(cowcode) 

outreg2 using RT_maerz10_a1, word bdec(4) tdec(4) e(N all) append



* Table 7.3:


logit ratif others pop gdppc trade_op /// 
veto_players polluter t t2 t3, cluster(cowcode) 

outreg2 using RT_maerz10_a1b, word bdec(4) tdec(4) e(N all)


logit ratif others_GDP pop gdppc trade_op /// 
veto_players polluter t t2 t3, cluster(cowcode) 

outreg2 using RT_maerz10_a1b, word bdec(4) tdec(4) e(N all) append


clogit ratif others_pop pop gdppc trade_op /// 
veto_players t t2 t3, group(cowcode) 

outreg2 using RT_maerz10_a1b, word bdec(4) tdec(4) e(N all) append


clogit ratif others_pop pop gdppc trade_op /// 
veto_players t t2 t3, group(treatyno) 

outreg2 using RT_maerz10_a1b, word bdec(4) tdec(4) e(N all) append




* Table 7.4:


logit ratif L_big_3 L_big_3b L_big_3c pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, cluster(cowcode) 

outreg2 using RT_lb3k, word bdec(4) tdec(4) e(N all)

logit ratif L_big_3 pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, cluster(cowcode) 

outreg2 using RT_lb3k, word bdec(4) tdec(4) e(N all) append

logit ratif L_big_3b pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, cluster(cowcode) 

outreg2 using RT_lb3k, word bdec(4) tdec(4) e(N all) append

logit ratif L_big_3c pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, cluster(cowcode) 

outreg2 using RT_lb3k, word bdec(4) tdec(4) e(N all) append



* Table 7.5:


logit ratif lUK lFrance lGER pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, cluster(cowcode) 

outreg2 using RT_lb3dk, word bdec(4) tdec(4) e(N all)

logit ratif lUK pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, cluster(cowcode) 

outreg2 using RT_lb3dk, word bdec(4) tdec(4) e(N all) append

logit ratif lFrance pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, cluster(cowcode) 

outreg2 using RT_lb3dk, word bdec(4) tdec(4) e(N all) append

logit ratif lGER pop gdppc trade_op /// 
veto_players polluter post_coldwar t t2 t3, cluster(cowcode) 

outreg2 using RT_lb3dk, word bdec(4) tdec(4) e(N all) append






clear
set more on
exit

